.. include:: ../references.txt

.. _cube:

************************
cube - Map cube analysis
************************

.. currentmodule:: gammapy.cube

Introduction
============

The `gammapy.cube` sub-package contains functions and classes to make maps
(counts, exposure, background), as well as to compute an effective PSF and
energy dispersion for a given set of observations.

It also contains classes that represent cube models (sky maps with an energy
axis), and classes to evaluate and fit those models to data.

Getting Started
===============

TODO: what to show here?

Using `gammapy.cube`
=====================

Gammapy tutorial notebooks that show examples using ``gammapy.cube``:

* :gp-notebook:`analysis_3d`
* :gp-notebook:`simulate_3d`
* :gp-notebook:`fermi_lat`

Reference/API
=============

.. automodapi:: gammapy.cube
    :no-inheritance-diagram:
    :include-all-objects:
